<?php
/**
 * @file
 * Contains \Drupal\pp_graphsearch\Form\PPGraphSearchAgentForm.
 */

namespace Drupal\pp_graphsearch\Form;
use Drupal\Component\Utility\UrlHelper;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\pp_graphsearch\PPGraphSearch;
use Drupal\semantic_connector\Entity\SemanticConnectorPPServerConnection;
use Drupal\semantic_connector\SemanticConnector;

/**
 * The form to add or edit a PoolParty GraphSearch agents.
 */
class PPGraphSearchAgentForm extends FormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'pp_graphsearch_agent_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $agent_id = '', $connection_id = '') {
    $config = (!empty($agent_id) && !empty($connection_id) ? PPGraphSearch::loadAgent($connection_id, $agent_id) : NULL);

    $form['source'] = array(
      '#type' => 'textfield',
      '#title' => t('Name'),
      '#description' => t('Name of the agent.'),
      '#size' => 35,
      '#maxlength' => 60,
      '#default_value' => (!is_null($config)) ? $config['source'] : '',
      '#required' => TRUE,
    );

    $form['url'] = array(
      '#type' => 'textfield',
      '#title' => t('RSS URL'),
      '#description' => t('RSS URL of the source.'),
      '#size' => 35,
      '#maxlength' => 255,
      '#default_value' => (!is_null($config)) ? $config['url'] : '',
      '#required' => TRUE,
    );

    /* The space key is not important for now
    $form['spaceKey'] = array(
      '#type' => 'textfield',
      '#title' => t('Type'),
      '#description' => t('The type of the source (e.g. internal, external) shown in a separate facet.'),
      '#size' => 35,
      '#maxlength' => 60,
      '#default_value' => (!is_null($config)) ? $config['spaceKey'] : '',
    );
    */

    $form['periodMillis'] = array(
      '#type' => 'select',
      '#title' => t('Crawling period'),
      '#description' => t('The period when the agent is to be re-crawled.'),
      '#options' => array(
        '3600000' => t('hourly'),
        '86400000' => t('daily'),
        '604800000' => t('weekly'),
      ),
      '#default_value' => (!is_null($config)) ? $config['periodMillis'] : '86400000',
      '#required' => TRUE,
    );

    // Update existing config.
    if (!is_null($config)) {
      $form['connection_id'] = array(
        '#type' => 'hidden',
        '#value' => $config['connection_id'],
      );
      $form['agentid'] = array(
        '#type' => 'hidden',
        '#value' => $config['id'],
      );
    }
    // Create a new config --> choose sOnr-configuration.
    else {
      $sonr_options = array();
      $connections = SemanticConnector::getConnectionsByType('pp_server');
      if (!empty($connections)) {
        foreach ($connections as $connection) {
          /** @var SemanticConnectorPPServerConnection $connection */
          $connection_config = $connection->getConfig();
          if (!empty($connection_config['graphsearch_configuration'])) {
            $sonr_options[$connection->id()] = $connection->getTitle();
          }
        }
      }
      $form['connection_id'] = array(
        '#type' => 'select',
        '#title' => t('PoolParty GraphSearch server'),
        '#description' => t('Choose the PoolParty GraphSearch server this agent will be created for.'),
        '#options' => $sonr_options,
        '#required' => TRUE,
      );
    }

    $form['save'] = array(
      '#type' => 'submit',
      '#value' => t('Save'),
    );
    $form['cancel'] = array(
      '#type' => 'link',
      '#title' => t('Cancel'),
      '#href' => 'admin/config/semantic-drupal/pp-graphsearch/agents',
    );

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!UrlHelper::isValid($form_state->getValue('url'), TRUE)) {
      $form_state->setErrorByName('url', t('The field URL must be a valid URL.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $pp_graphsearch_api = SemanticConnector::getConnection('pp_server', $form_state->getValue('connection_id'))->getApi('sonr');
    $config = array(
      'username' => \Drupal::currentUser()->getAccountName(),
      'source' => $form_state->getValue('source'),
      'url' => $form_state->getValue('url'),
      'periodMillis' => $form_state->getValue('periodMillis'),
    );

    if (!empty($form_state->getValue('agentid'))) {
      $response = $pp_graphsearch_api->updateAgent($form_state->getValue('agentid'), $config);
    }
    else {
      $response = $pp_graphsearch_api->addAgent($config);
    }
    if ($response) {
      drupal_set_message(t('PoolParty GraphSearch agent %title has been saved.', array('%title' => $form_state->getValue('source'))));
    }
    else {
      drupal_set_message(t('PoolParty GraphSearch agent %title has not been saved.', array('%title' => $form_state->getValue('source'))), 'error');
    }

    $form_state->setRedirectUrl(Url::fromRoute('pp_graphsearch.list_agents'));
  }
}
?>