<?php

/**
 * @file
 * Contains \Drupal\pp_graphsearch\PPGraphSearchConfigListBuilder.
 */

namespace Drupal\pp_graphsearch;
use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Config\Entity\ConfigEntityListBuilder;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\pp_graphsearch\Entity\PPGraphSearchConfig;

class PPGraphSearchConfigListBuilder extends ConfigEntityListBuilder
{
  /**
   * {@inheritdoc}
   */
  public function buildHeader() {
    $header['title'] = t('Title');
    $header['server'] = t('PoolParty GraphSearch Server');
    $header['project'] = t('Selected project');
    $header['available'] = t('Available on page');
    return $header + parent::buildHeader();
  }
  /**
   * {@inheritdoc}
   */
  public function buildRow(EntityInterface $entity) {
    /** @var PPGraphSearchConfig $entity */
    $graphsearch = new PPGraphSearch($entity);

    $row['title'] = new FormattableMarkup('<div class="semantic-connector-led" data-server-id="@connectionid" data-server-type="pp-server" title="@servicetitle"></div>@entitytitle', ['@connectionid' => $entity->getConnection()->id(), '@servicetitle' => t('Checking service'), '@entitytitle' => $entity->get('title')]);
    $row['server'] = Link::fromTextAndUrl($entity->getConnection()->getTitle(), Url::fromUri($entity->getConnection()->getUrl()))->toString();

    // Get the project label.
    $project_id = $entity->getProjectID();
    $connection_config = $entity->getConnection()->getConfig();
    $project_label = 'project label not found';
    if (isset($connection_config['projects'])) {
      foreach ($connection_config['projects'] as $project) {
        if ($project['id'] == $project_id) {
          $project_label = $project['title'];
          break;
        }
      }
    }
    $row['project'] = $project_label;

    $path = $graphsearch->getBlockPath();
    $path = empty($path) ? new FormattableMarkup('<div class="semantic-connector-italic">@notyetset</div>', ['@notyetset' => t('not yet set')]) : Link::fromTextAndUrl($path, Url::fromUri('base:' . $path))->toString();
    $row['available'] = $path;

    //$row['basePath'] = $entity->getBasePath();
    return $row + parent::buildRow($entity);
  }

  public function buildOperations(EntityInterface $entity) {
    $build = array(
      '#type' => 'operations',
      '#links' => $this->getOperations($entity),
    );

    if (isset($build['#links']['edit'])) {
      $build['#links']['edit']['url'] = \Drupal\Core\Url::fromRoute('entity.pp_graphsearch.edit_config_form', array('pp_graphsearch' => $entity->id()));
    }

    $build['#links']['clone'] = array(
      'title' => t('Clone'),
      'url' => Url::fromRoute('entity.pp_graphsearch.clone_form', array('pp_graphsearch' => $entity->id())),
      'weight' => 1000,
    );

    return $build;
  }

  /**
   * Gets this list's default operations.
   *
   * This method calls the parent method, then adds in an operation
   * to create an entity of this type.
   *
   * @param \Drupal\Core\Entity\EntityInterface $entity
   *   The entity the operations are for.
   *
   * @return array
   *   The array structure is identical to the return value of
   *   self::getOperations().
   */
  /*public function getDefaultOperations(SemanticConnectorConnectionInterface $entity) {
    $operations = parent::getDefaultOperations($entity);

    $url = \Drupal\Core\Url::fromRoute('entity.pp_server_connection.edit_form', ['pp_server_connection' => $entity->id()]);
    $operations['edit'] = array(
      'title' => $this->t('Edit'),
      'weight' => 10,
      'url' =>  $url,
    );

    return $operations;
  }*/
}